Fetch information about all gene sets in the Gesel database.

fetchAllSets(species, config = NULL)

Arguments

species

String containing the NCBI taxonomy ID of the species of interest.

config

Configuration list, typically created by newConfig. If NULL, the default configuration is used.

Value

Data frame of gene set information. Each row represents a gene set and contains:

  • name, string containing the name of the gene set.

  • description, string containing a description of the gene set.

  • size, integer specifying the number of genes in this gene set.

  • collection, integer containing the collection index of the collection that contains this gene set. The collection index refers to a row of the data frame returned by fetchAllCollections.

  • number, integer containing the position of the gene set inside the specified collection. The set index of the current gene set is defined by adding number - 1 to the collection's start.

Details

If this function is called once, the data frame will be cached in memory and re-used in subsequent calls to this function. The cached data will also be used to speed up calls to fetchSomeSets.

Author

Aaron Lun

Examples

out <- fetchAllSets("9606")
head(out)
#>         name                                        description size collection
#> 1 GO:0000002                   mitochondrial genome maintenance   11          1
#> 2 GO:0000003                                       reproduction    4          1
#> 3 GO:0000009             alpha-1,6-mannosyltransferase activity    2          1
#> 4 GO:0000010          trans-hexaprenyltranstransferase activity    2          1
#> 5 GO:0000012                         single strand break repair   10          1
#> 6 GO:0000014 single-stranded DNA endodeoxyribonuclease activity    9          1
#>   number
#> 1      1
#> 2      2
#> 3      3
#> 4      4
#> 5      5
#> 6      6