Quickly get the sizes of all gene set collections in the Gesel database. This is more efficient than fetchAllCollections when only the sizes are of interest.

fetchCollectionSizes(species, config = NULL)

Arguments

species

String containing the NCBI taxonomy ID of the species of interest.

config

Configuration list, typically created by newConfig. If NULL, the default configuration is used.

Value

Integer vector containing the size of each collection (i.e., the number of gene sets).

Author

Aaron Lun

Examples

head(fetchCollectionSizes("9606"))
#> [1] 18864   302  3555   196  1839   925