Fetch the list of available gene identifier types for this species.

fetchGeneTypes(species, config = NULL)

Arguments

species

String specifying the taxonomy ID of the species of interest.

config

Configuration list, typically created by newConfig. If NULL, the default configuration is used.

Value

Character vector of the available types.

Details

In older versions (0.1.0) of the Gesel gene annotation file specification, an explicit listing of types was not generated, so this function will just assume that "ensembl", "entrez" and "symbol" are available.

Author

Aaron Lun

Examples

fetchGeneTypes("9606")
#> [1] "entrez"  "ensembl" "symbol" 
fetchGeneTypes("10090")
#> [1] "entrez"  "ensembl" "symbol"