Get the version of the Gesel gene annotation file specification used by the species of interest.

fetchGeneVersion(species, config = NULL)

Arguments

species

String specifying the taxonomy ID of the species of interest.

config

Configuration list, typically created by newConfig. If NULL, the default configuration is used.

Value

String containing the version of the Gesel gene annotation file specification.

Author

Aaron Lun

Examples

fetchGeneVersion("9606")
#> [1] "0.2.0"