Create a mapping of gene names/identifiers (Ensembl, symbol, etc.) to their Gesel gene indices.

mapGenesByName(species, type, ignore.case = FALSE, config = NULL)

Arguments

species

String specifying the taxonomy ID of the species of interest.

type

String specifying the type of name. This is typically one of "symbol", "entrez", and "ensembl",

ignore.case

Boolean indicating whether case should be ignored.

config

Configuration list, typically created by newConfig. If NULL, the default configuration is used.

Value

Named list of integer vectors. Each name corresponds to an name of the specified type, and each vector contains the identities of genes associated with that name (after ignoring case, if ignore.case=TRUE). Each gene is identified as a row index into the data frame returned by fetchAllGenes.

Author

Aaron Lun

Examples

mapping <- mapGenesByName("9606", type="symbol")

# Taking it for a spin:
found <- mapping[["SNAP25"]]
fetchAllGenes("9606")$symbol[found]
#> [[1]]
#> [1] "SNAP25"
#>