Fetch identifiers for all genes.
fetchAllGenes(species, types = NULL, config = NULL)String specifying the taxonomy ID of the species of interest.
Character vector specifying the types of gene identifiers to return.
If NULL, the available types are determined from fetchGeneTypes.
Configuration list, typically created by newConfig.
If NULL, the default configuration is used.
Data frame where each row represents a gene.
Each column corresponds to one of the types and is a list of character vectors.
Each vector contains identifiers of the specified type for each gene.
out <- fetchAllGenes("9606")
head(out)
#> entrez ensembl symbol
#> 1 1 ENSG0000.... A1BG
#> 2 2 ENSG0000.... A2M
#> 3 9 ENSG0000.... NAT1
#> 4 10 ENSG0000.... NAT2
#> 5 12 ENSG0000.... SERPINA3
#> 6 13 ENSG0000.... AADAC
head(out$symbol)
#> [[1]]
#> [1] "A1BG"
#>
#> [[2]]
#> [1] "A2M"
#>
#> [[3]]
#> [1] "NAT1"
#>
#> [[4]]
#> [1] "NAT2"
#>
#> [[5]]
#> [1] "SERPINA3"
#>
#> [[6]]
#> [1] "AADAC"
#>