Fetch the list of available gene identifier types for this species.
fetchGeneTypes(species, config = NULL)String specifying the taxonomy ID of the species of interest.
Configuration list, typically created by newConfig.
If NULL, the default configuration is used.
Character vector of the available types.
In older versions (0.1.0) of the Gesel gene annotation file specification, an explicit listing of types was not generated,
so this function will just assume that "ensembl", "entrez" and "symbol" are available.
fetchGeneTypes("9606")
#> [1] "entrez" "ensembl" "symbol"
fetchGeneTypes("10090")
#> [1] "entrez" "ensembl" "symbol"