Fetch the details of some gene set collections from the Gesel database. This can be more efficient than fetchAllCollections when only a few collections are of interest.

fetchSomeCollections(species, collections, config = NULL)

Arguments

species

String containing the NCBI taxonomy ID of the species of interest.

collections

Integer vector containing collection indices. Each entry refers to a row of the data frame returned by fetchAllCollections).

config

Configuration list, typically created by newConfig. If NULL, the default configuration is used.

Value

Data frame with the same columns as the return value of fetchAllCollections, where each row corresponds to an entry of collections.

Details

Every time this function is called, information from the requested collections will be added to an in-memory cache. Subsequent calls to this function will re-use as many of the cached collections as possible before making new requests to the Gesel database.

If fetchAllCollections was previously called, its cached data will be used by fetchSomeCollections to avoid extra requests to the database. If collections is large, it may be more efficient to call fetchAllCollections to prepare the cache before calling this function.

Author

Aaron Lun

Examples

fetchSomeCollections("9606", 1:5)
#>                                                title
#> 1                                      Gene ontology
#> 2                   MSigDB positional gene sets (C1)
#> 3 MSigDB chemical and genetic perturbations (C2 CGP)
#> 4                 MSigDB canonical pathways (C2 PID)
#> 5            MSigDB canonical pathways (C2 Reactome)
#>                                                                                                                 description
#> 1 Gene sets defined from the Gene Ontology (version 2022-07-01), sourced from the Bioconductor package org.Hs.eg.db 3.16.0.
#> 2      Gene annotations for this collection are derived from the Chromosome and Karyotype band tracks from Ensembl BioMart.
#> 3                                     Gene sets that represent expression signatures of genetic and chemical perturbations.
#> 4                                                                  Gene sets derived from the Pathway Interaction Database.
#> 5                       Reactome gene sets are derived from Reactome and have been filtered to remove inter-set redundancy.
#>   maintainer
#> 1  Aaron Lun
#> 2  Aaron Lun
#> 3  Aaron Lun
#> 4  Aaron Lun
#> 5  Aaron Lun
#>                                                                         source
#> 1 https://github.com/LTLA/gesel-feedstock/blob/gene-ontology-v1.0.0/go/build.R
#> 2           https://github.com/LTLA/gesel-feedstock/blob/master/msigdb/build.R
#> 3           https://github.com/LTLA/gesel-feedstock/blob/master/msigdb/build.R
#> 4           https://github.com/LTLA/gesel-feedstock/blob/master/msigdb/build.R
#> 5           https://github.com/LTLA/gesel-feedstock/blob/master/msigdb/build.R
#>   start  size
#> 1     1 18933
#> 2 18934   300
#> 3 19234  3405
#> 4 22639   196
#> 5 22835  1654