mapGenesByName.RdCreate a mapping of gene names/identifiers (Ensembl, symbol, etc.) to their Gesel gene indices.
mapGenesByName(species, type, ignore.case = FALSE, config = NULL)String specifying the taxonomy ID of the species of interest.
String specifying the type of name.
This is typically one of "symbol", "entrez", and "ensembl",
Boolean indicating whether case should be ignored.
Configuration list, typically created by newConfig.
If NULL, the default configuration is used.
Named list of integer vectors.
Each name corresponds to an name of the specified type,
and each vector contains the identities of genes associated with that name (after ignoring case, if ignore.case=TRUE).
Each gene is identified as a row index into the data frame returned by fetchAllGenes.
mapping <- mapGenesByName("9606", type="symbol")
# Taking it for a spin:
found <- mapping[["SNAP25"]]
fetchAllGenes("9606")$symbol[found]
#> [[1]]
#> [1] "SNAP25"
#>